[Piglit] [PATCH] Fix clearbuffer-display-lists test case
Anuj Phogat
anuj.phogat at gmail.com
Tue Feb 7 11:55:55 PST 2012
glClear(GL_COLOR_BUFFER_BIT) before probing the color buffer.
Test occasionally fails without this call.
Reported-by: Eric Anholt <eric at anholt.net>
Signed-off-by: Anuj Phogat <anuj.phogat at gmail.com>
---
tests/spec/gl-3.0/api/clearbuffer-display-lists.c | 6 ++++--
1 files changed, 4 insertions(+), 2 deletions(-)
diff --git a/tests/spec/gl-3.0/api/clearbuffer-display-lists.c b/tests/spec/gl-3.0/api/clearbuffer-display-lists.c
index 8595076..7924f91 100644
--- a/tests/spec/gl-3.0/api/clearbuffer-display-lists.c
+++ b/tests/spec/gl-3.0/api/clearbuffer-display-lists.c
@@ -44,8 +44,10 @@ void piglit_init(int argc, char **argv)
bool pass = true;
piglit_require_gl_version(30);
- /* Probe the color buffer before creating display list. color buffers
- * are by default cleared to (0.0, 0.0, 0.0, 1.0)
+ glClear(GL_COLOR_BUFFER_BIT);
+
+ /* Probe the color buffer before creating display list. Default clear
+ * color is (0.0, 0.0, 0.0, 1.0)
*/
pass = piglit_probe_rect_rgba(0, 0,
piglit_width, piglit_height,
--
1.7.7.4
More information about the Piglit
mailing list